@@ -1,10 +1,10 @@
 
-#' Plots a three dimensional array
+#' Plots three dimensional y values for quantile plots
 #' 
-#' 1st margin sets line values, 2nd sets variables, 3rd quantiles.
+#' 1st margin of $Y sets line values, 2nd sets variables, 3rd quantiles.
 #'
-#' @param yarray 3 dimensional array to use for Y values
-#' @param x numeric vector specifying x axis
+#' @param input list containing 3 dimensional array to use for Y values, \code{$y}
+#' and vector of corresponding x values \code{$x}.
 #' @param grid Logical. Plot with a grid?
 #' @param colvec color vector of same length as 2nd margin.
 #' @param lwdvec lwd vector of same length as 2nd margin.
@@ -22,22 +22,28 @@
 #' @export
 #'
 #' @examples
-#' y <- ctStanTIpredeffects(ctstantestfit,plot=FALSE)
-#' x<-ctstantestfit$data$tipreds[order(ctstantestfit$data$tipreds[,1]),1]
-#' ctPlotArray(y,x)
-ctPlotArray <- function(yarray,x,
-  grid=TRUE,
+#' input<-ctStanTIpredeffects(ctstantestfit, plot=FALSE, whichpars='CINT', 
+#'  nsamples=10,nsubjects=10)
+#'     
+#' ctPlotArray(input=input)
+ctPlotArray <- function(input,
+  grid=FALSE,
   colvec='auto',lwdvec='auto',ltyvec='auto',typevec='auto',
-  plotcontrol=list(ylab='Array values', xlab='X values',xaxs='i'),
-  legend=TRUE,legendcontrol=list(x='topright'),
-  polygon=TRUE, polygonalpha=.1,polygoncontrol=list(border=NA,steps=50)){
+  plotcontrol=list(ylab='Array values',xaxs='i'),
+  legend=TRUE,legendcontrol=list(),
+  polygon=TRUE, polygonalpha=.1,polygoncontrol=list(steps=25)){
+  
+  if(class(input)!='list') stop('Input must be a list containing y and x subobjects!')
+
+  x <- input$x
+  if(length(dim(input$y))!=3) stop('$y subobject must have 3 dimensions!')
+  if(length(x) != length(input$y[,1,1])) stop ('Length of 1st margin of $y and $x must be the same!')
   
-  # browser()
   separate=FALSE
-  nvars<-dim(yarray)[2]
-  
+  nvars<-dim(input$y)[2]
+
   plotcontrolpars <- c('ylab','xlab')
-  plotcontroldefaults <- c('Array values','X values')
+  plotcontroldefaults <- c('Array values',colnames(input$x))
   for(i in 1:length(plotcontrolpars)) {
     if(is.null(plotcontrol[[plotcontrolpars[i]]])) plotcontrol[[plotcontrolpars[i]]] <- plotcontroldefaults[i]
   }
@@ -48,24 +54,30 @@ ctPlotArray <- function(yarray,x,
     if(is.null(legendcontrol[[legendcontrolpars[i]]])) legendcontrol[[legendcontrolpars[i]]] <- legendcontroldefaults[i]
   }
   
-  polygoncontrolpars <- c('border')
-  polygoncontroldefaults <- c(NA)
-  for(i in 1:length(polygoncontrolpars)) {
-    if(is.null(polygoncontrol[[polygoncontrolpars[i]]])) polygoncontrol[[polygoncontrolpars[i]]] <- polygoncontroldefaults[i]
+  if(is.null(legendcontrol$legend)){
+   if(!is.null(dimnames(input$y)[2])) {
+     legendcontrol$legend <- dimnames(input$y)[2] 
+   } else  legend <- FALSE
   }
   
+  # polygoncontrolpars <- c('border')
+  # polygoncontroldefaults <- c(NA)
+  # for(i in 1:length(polygoncontrolpars)) {
+  #   if(is.null(polygoncontrol[[polygoncontrolpars[i]]])) polygoncontrol[[polygoncontrolpars[i]]] <- polygoncontroldefaults[i]
+  # }
+  
   if(all(ltyvec=='auto')) ltyvec = 1:nvars
   if(all(lwdvec=='auto')) lwdvec = rep(3,nvars)
   if(all(colvec=='auto')) colvec = rainbow(nvars,v=.9)
   if(all(typevec=='auto')) typevec = rep('l',nvars)
   # if(all(mainvec=='auto')){
-  #   if(separate) mainvec=dimnames(yarray)[[2]] else mainvec =rep(ifelse(is.null(plotcontrol$main),'',plotcontrol$main),nvars)
+  #   if(separate) mainvec=dimnames(input$y)[[2]] else mainvec =rep(ifelse(is.null(plotcontrol$main),'',plotcontrol$main),nvars)
   # }
-  
+
   plotargs<-plotcontrol
   plotargs$x <- x
-  if(!separate && is.null(plotcontrol$ylim)) plotargs$ylim = range(yarray,na.rm=TRUE)+ c(0,
-    (max(yarray,na.rm=TRUE) - min(yarray,na.rm=TRUE)) /3)
+  if(!separate && is.null(plotcontrol$ylim)) plotargs$ylim = range(input$y,na.rm=TRUE)+ c(0,
+    (max(input$y,na.rm=TRUE) - min(input$y,na.rm=TRUE)) /3)
   plotargs$xlim = range(x,na.rm=TRUE)
   
   ctpolyargs<-polygoncontrol
@@ -87,20 +99,20 @@ ctPlotArray <- function(yarray,x,
   
   #confidence
   if(polygon) {
-    for(pari in c(1:dim(yarray)[2],dim(yarray)[2]:1)){
-      ctpolyargs$col=adjustcolor(colvec[pari],alpha.f=max(c(.004,polygonalpha/ctpolyargs$steps)))
-      ctpolyargs$x=plotargs$x[!is.na(plotargs$x) & !is.na(yarray[,pari,2])]
-      ctpolyargs$y=yarray[,pari,2][!is.na(plotargs$x) & !is.na(yarray[,pari,2])] #predict(loess(yarray[,pari,2]~ctpolyargs$x))
-      ctpolyargs$yhigh = yarray[,pari,3][!is.na(plotargs$x) & !is.na(yarray[,pari,2])] #predict(loess(yarray[,pari,3]~ctpolyargs$x))
-      ctpolyargs$ylow = yarray[,pari,1][!is.na(plotargs$x) & !is.na(yarray[,pari,2])]#predict(loess(yarray[,pari,1]~ctpolyargs$x))
+    for(pari in c(1:dim(input$y)[2],dim(input$y)[2]:1)){
+      ctpolyargs$col=adjustcolor(colvec[pari],alpha.f=max(c(.004,polygonalpha/(4*sqrt(ctpolyargs$steps)))))
+      ctpolyargs$x=plotargs$x[!is.na(plotargs$x) & !is.na(input$y[,pari,2])]
+      ctpolyargs$y=input$y[,pari,2][!is.na(plotargs$x) & !is.na(input$y[,pari,2])] #predict(loess(input$y[,pari,2]~ctpolyargs$x))
+      ctpolyargs$yhigh = input$y[,pari,3][!is.na(plotargs$x) & !is.na(input$y[,pari,2])] #predict(loess(input$y[,pari,3]~ctpolyargs$x))
+      ctpolyargs$ylow = input$y[,pari,1][!is.na(plotargs$x) & !is.na(input$y[,pari,2])]#predict(loess(input$y[,pari,1]~ctpolyargs$x))
       
       do.call(ctPoly,ctpolyargs) 
     }
   }
   
-  for(pari in c(1:dim(yarray)[2],dim(yarray)[2]:1)){
+  for(pari in c(1:dim(input$y)[2],dim(input$y)[2]:1)){
     for(qi in 1:3){
-      plotargs$y = yarray[,pari,qi]#predict(loess(yarray[,pari,qi]~plotargs$x))
+      plotargs$y = input$y[,pari,qi]#predict(loess(input$y[,pari,qi]~plotargs$x))
       plotargs$col=colvec[pari]
       plotargs$lwd=ifelse(qi==2,lwdvec[pari],1)
       plotargs$lty=ltyvec[pari]
@@ -110,8 +122,8 @@ ctPlotArray <- function(yarray,x,
       do.call(points,plotargs)
     }
     
-    if(separate & legend) {
-      legargs$legend=dimnames(yarray)[[2]][pari]
+    if(separate && legend) {
+      legargs$legend=dimnames(input$y)[[2]][pari]
       legargs$col = plotargs$col
       legargs$lty = plotargs$lty
       legargs$text.col = plotargs$col
@@ -121,7 +133,7 @@ ctPlotArray <- function(yarray,x,
   }
   
   if(!separate & legend) {
-    legargs$legend=dimnames(yarray)[[2]]
+    legargs$legend=dimnames(input$y)[[2]]
     legargs$col = colvec
     legargs$lty = ltyvec
     legargs$text.col = colvec
